==> aliyun-python-sdk-cloudauth-2.0.6.tar.gz: aliyun-python-sdk-cloudauth-2.0.6/aliyunsdkcloudauth/request/v20190307/VerifyDeviceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudauth.endpoint import endpoint_data

class VerifyDeviceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'VerifyDevice','cloudauth')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_CertifyData(self):
		return self.get_query_params().get('CertifyData')

	def set_CertifyData(self,CertifyData):
		self.add_query_param('CertifyData',CertifyData)

	def get_AppVersion(self):
		return self.get_query_params().get('AppVersion')

	def set_AppVersion(self,AppVersion):
		self.add_query_param('AppVersion',AppVersion)

	def get_CertifyId(self):
		return self.get_query_params().get('CertifyId')

	def set_CertifyId(self,CertifyId):
		self.add_query_param('CertifyId',CertifyId)

==> aliyun-python-sdk-cloudauth-2.0.18.tar.gz: aliyun-python-sdk-cloudauth-2.0.18/aliyunsdkcloudauth/request/v20190307/VerifyDeviceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudauth.endpoint import endpoint_data

class VerifyDeviceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'VerifyDevice','cloudauth')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ExtInfo(self):
		return self.get_body_params().get('ExtInfo')

	def set_ExtInfo(self,ExtInfo):
		self.add_body_params('ExtInfo', ExtInfo)

	def get_CertifyData(self):
		return self.get_query_params().get('CertifyData')

	def set_CertifyData(self,CertifyData):
		self.add_query_param('CertifyData',CertifyData)

	def get_AppVersion(self):
		return self.get_query_params().get('AppVersion')

	def set_AppVersion(self,AppVersion):
		self.add_query_param('AppVersion',AppVersion)

	def get_CertifyId(self):
		return self.get_query_params().get('CertifyId')

	def set_CertifyId(self,CertifyId):
		self.add_query_param('CertifyId',CertifyId)
